@@ -11,19 +11,15 @@ create_join_parser = subparsers.add_parser("create-join")
 create_join_parser.add_argument("--schema", default="-")
 create_join_parser.add_argument("--output", default="-")
 
-create_key_parser = subparsers.add_parser("create-key")
-create_key_parser.add_argument("--schema", default="-")
-create_key_parser.add_argument("--output", default="-")
-
 
 def main():
     args = parser.parse_args()
 
+    if args.command == "create-agg":
+        from .create_agg import cli
+
+        cli(args)
     if args.command == "create-join":
         from .create_join import cli
 
-        cli(args)
-    elif args.command == "create-key":
-        from .create_key import cli
-
         cli(args)
